pub struct Signed<T, V>where
T: BorshSerialize,
V: BorshSerialize,{
pub msg: T,
pub signature: V,
}Fields
msg: Tsignature: VTrait Implementations
Sourceimpl<T, V> BorshDeserialize for Signed<T, V>
impl<T, V> BorshDeserialize for Signed<T, V>
fn deserialize_reader<__R>(reader: &mut __R) -> Result<Signed<T, V>, Error>where
__R: Read,
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl<T, V> BorshSerialize for Signed<T, V>where
T: BorshSerialize,
V: BorshSerialize,
impl<T, V> BorshSerialize for Signed<T, V>where
T: BorshSerialize,
V: BorshSerialize,
Sourceimpl<T> Debug for Signed<T, ValidatorSignature>where
T: Debug + BorshSerialize,
impl<T> Debug for Signed<T, ValidatorSignature>where
T: Debug + BorshSerialize,
Sourceimpl<'de, T, V> Deserialize<'de> for Signed<T, V>
impl<'de, T, V> Deserialize<'de> for Signed<T, V>
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<Signed<T, V>, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<Signed<T, V>, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Display for Signed<ValidatorCandidacy, ValidatorSignature>
impl Display for Signed<ValidatorCandidacy, ValidatorSignature>
Sourceimpl<T> Display for Signed<T, ValidatorSignature>where
T: Display + BorshSerialize,
impl<T> Display for Signed<T, ValidatorSignature>where
T: Display + BorshSerialize,
impl<T, V> Eq for Signed<T, V>
Sourceimpl<T, V> Ord for Signed<T, V>
impl<T, V> Ord for Signed<T, V>
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
1.21.0 (const: unstable) · Sourcefn min(self, other: Self) -> Selfwhere
Self: Sized,
fn min(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the minimum of two values. Read more
Sourceimpl<T, V> PartialOrd for Signed<T, V>
impl<T, V> PartialOrd for Signed<T, V>
Sourceimpl<T, V> Serialize for Signed<T, V>
impl<T, V> Serialize for Signed<T, V>
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl<T, V> StructuralPartialEq for Signed<T, V>